@@ -7,7 +7,7 @@ const Util = imports.misc.util;
 const PopupMenu = imports.ui.popupMenu;
 const UPowerGlib = imports.gi.UPowerGlib;
 const Settings = imports.ui.settings;
-const Calendar = imports.applets['calendar@cinnamon.org'].calendar;
+const Calendar = require('./calendar');
 const CinnamonDesktop = imports.gi.CinnamonDesktop;
 
 String.prototype.capitalize = function() {
@@ -32,15 +32,9 @@ function _onVertSepRepaint (area)
     cr.$dispose();
 };
 
-function MyApplet(orientation, panel_height, instance_id) {
-    this._init(orientation, panel_height, instance_id);
-}
-
-MyApplet.prototype = {
-    __proto__: Applet.TextApplet.prototype,
-
-    _init: function(orientation, panel_height, instance_id) {
-        Applet.TextApplet.prototype._init.call(this, orientation, panel_height, instance_id);
+class CinnamonCalendarApplet extends Applet.TextApplet {
+    constructor(orientation, panel_height, instance_id) {
+        super(orientation, panel_height, instance_id);
 
         this.setAllowedLayout(Applet.AllowedLayout.BOTH);
 
@@ -49,6 +43,7 @@ MyApplet.prototype = {
             this.orientation = orientation;
 
             this._initContextMenu();
+            this.menu.setCustomStyleClass('calendar-background');
 
             // Date
             this._date = new St.Label();
@@ -73,6 +68,17 @@ MyApplet.prototype = {
             this.settings.bind("use-custom-format", "use_custom_format", this._onSettingsChanged);
             this.settings.bind("custom-format", "custom_format", this._onSettingsChanged);
 
+            /* FIXME: Add gobject properties to the WallClock class to allow easier access from
+             * its clients, and possibly a separate signal to notify of updates to these properties
+             * (though GObject "changed" would be sufficient.) */
+            this.desktop_settings = new Gio.Settings({ schema_id: "org.cinnamon.desktop.interface" });
+            this.desktop_settings.connect("changed::clock-use-24h", Lang.bind(this, function(key) {
+                this._onSettingsChanged();
+            }));
+            this.desktop_settings.connect("changed::clock-show-seconds", Lang.bind(this, function(key) {
+                this._onSettingsChanged();
+            }));
+
             this.clock = new CinnamonDesktop.WallClock();
             this.clock_notify_id = 0;
 
@@ -87,61 +93,66 @@ MyApplet.prototype = {
         catch (e) {
             global.logError(e);
         }
-    },
+    }
 
-    _clockNotify: function(obj, pspec, data) {
+    _clockNotify(obj, pspec, data) {
         this._updateClockAndDate();
-    },
+    }
 
-    on_applet_clicked: function(event) {
+    on_applet_clicked(event) {
         this.menu.toggle();
-    },
+    }
 
-    _onSettingsChanged: function() {
+    _onSettingsChanged() {
         this._updateFormatString();
         this._updateClockAndDate();
-    },
+    }
 
-    on_custom_format_button_pressed: function() {
+    on_custom_format_button_pressed() {
         Util.spawnCommandLine("xdg-open http://www.foragoodstrftime.com/");
-    },
+    }
 
-    _onLaunchSettings: function() {
+    _onLaunchSettings() {
         this.menu.close();
         Util.spawnCommandLine("cinnamon-settings calendar");
-    },
+    }
 
-    _updateFormatString: function() {
+    _updateFormatString() {
         let in_vertical_panel = (this.orientation == St.Side.LEFT || this.orientation == St.Side.RIGHT);
 
         if (this.use_custom_format) {
             if (!this.clock.set_format_string(this.custom_format)) {
                 global.logError("Calendar applet: bad time format string - check your string.");
-                this.clock.set_format_string("FORMAT ERROR %l:%M %p");
+                this.clock.set_format_string("~CLOCK FORMAT ERROR~ %l:%M %p");
             }
         } else if (in_vertical_panel) {
-           /* First removes the date, then changes single splits 24hr mode, then removes "AM/PM" in 12hr mode, finaly replacing : with a newline */
-           let current_format = this.clock.get_default_time_format();
-           let vertical_format = current_format.replace('%A %B %e, ', '').replace('%R', '%H%n%M').replace(' %p', '').replace(new RegExp(":", 'g'), "%n");
-           this.clock.set_format_string(vertical_format);
+            let use_24h = this.desktop_settings.get_boolean("clock-use-24h");
+            let show_seconds = this.desktop_settings.get_boolean("clock-show-seconds");
+
+            if (use_24h) {
+                if (show_seconds) {
+                    this.clock.set_format_string("%H%n%M%n%S");
+                } else {
+                    this.clock.set_format_string("%H%n%M%");
+                }
+            } else {
+                if (show_seconds) {
+                    this.clock.set_format_string("%l%n%M%n%S");
+                } else {
+                    this.clock.set_format_string("%l%n%M%");
+                }
+            }
         } else {
             this.clock.set_format_string(null);
         }
-    },
+    }
 
-    _updateClockAndDate: function() {
+    _updateClockAndDate() {
         let label_string = this.clock.get_clock();
-        let in_vertical_panel = (this.orientation == St.Side.LEFT || this.orientation == St.Side.RIGHT);
 
-        if (!this.use_custom_format && !in_vertical_panel) {
+        if (!this.use_custom_format) {
             label_string = label_string.capitalize();
         }
-        else {
-            let vertical_format = this.clock.get_default_time_format();
-            /* First removes the date, then changes single splits 24hr mode, then removes "AM/PM" in 12hr mode, finaly replacing : with a newline */
-            vertical_format = vertical_format.replace('%A %B %e, ', '').replace('%R', '%H%n%M').replace(' %p', '').replace(new RegExp(":", 'g'), "%n");
-            label_string = this.clock.get_clock_for_format(vertical_format);
-        }
 
         this.set_applet_label(label_string);
 
@@ -151,9 +162,9 @@ MyApplet.prototype = {
 
         this._date.set_text(dateFormattedFull);
         this.set_applet_tooltip(dateFormattedFull);
-    },
+    }
 
-    on_applet_added_to_panel: function() {
+    on_applet_added_to_panel() {
         this._onSettingsChanged();
 
         if (this.clock_notify_id == 0) {
@@ -162,16 +173,16 @@ MyApplet.prototype = {
 
         /* Populates the calendar so our menu allocation is correct for animation */
         this._updateCalendar();
-    },
+    }
 
-    on_applet_removed_from_panel: function() {
+    on_applet_removed_from_panel() {
         if (this.clock_notify_id > 0) {
             this.clock.disconnect(this.clock_notify_id);
             this.clock_notify_id = 0;
         }
-    },
+    }
 
-    _initContextMenu: function () {
+    _initContextMenu () {
         this.menu = new Applet.AppletPopupMenu(this, this.orientation);
         this.menuManager.addMenu(this.menu);
 
@@ -181,23 +192,21 @@ MyApplet.prototype = {
                 this._updateCalendar();
             }
         }));
-    },
+    }
 
-    _updateCalendar: function () {
+    _updateCalendar () {
         let now = new Date();
 
         this._calendar.setDate(now, true);
-    },
+    }
 
-    on_orientation_changed: function (orientation) {
+    on_orientation_changed (orientation) {
         this.orientation = orientation;
         this.menu.setOrientation(orientation);
         this._onSettingsChanged();
     }
-
-};
+}
 
 function main(metadata, orientation, panel_height, instance_id) {
-    let myApplet = new MyApplet(orientation, panel_height, instance_id);
-    return myApplet;
+    return new CinnamonCalendarApplet(orientation, panel_height, instance_id);
 }
